@@ -14,22 +14,23 @@ Some helper methods
 
 from sqlalchemy.engine.url import make_url
 
-from zope.component import getService, getGlobalServices, getUtilitiesFor, getUtility
-from zope.component.utility import GlobalUtilityService
+from zope.component import getUtilitiesFor, getUtility
 from zope.component.interfaces import IUtilityService, ComponentLookupError
-from zope.component.servicenames import Utilities 
 
 from z3c.sqlalchemy.interfaces import ISQLAlchemyWrapper
-from z3c.sqlalchemy.postgres import ZopePostgresWrapper, PythonPostgresWrapper 
-from z3c.sqlalchemy.base import BaseWrapper, ZopeBaseWrapper
+from z3c.sqlalchemy.postgres import ZopePostgresWrapper
+from z3c.sqlalchemy.base import ZopeWrapper
 
 __all__ = ('createSQLAlchemyWrapper', 'registerSQLAlchemyWrapper', 'allRegisteredSQLAlchemyWrappers', 'getSQLAlchemyWrapper',
            'createSAWrapper', 'registerSAWrapper', 'allRegisteredSAWrappers', 'getSAWrapper', 'allSAWrapperNames')
 
 registeredWrappers = {}
 
-def createSAWrapper(dsn, model=None, forZope=False, name=None, transactional=True, 
-                    engine_options={}, session_options={}, **kw):
+def createSAWrapper(dsn, model=None, name=None, transactional=True, 
+                    engine_options={}, 
+                    session_options={}, 
+                    extension_options={},
+                    **kw):
     """ Convenience method to generate a wrapper for a DSN and a model.
         This method hides all database related magic from the user. 
 
@@ -39,9 +40,6 @@ def createSAWrapper(dsn, model=None, forZope=False, name=None, transactional=Tru
         a named utility implementing IModelProvider or a method/callable returning an
         instance of model.Model.
 
-        'forZope' - set this to True in order to obtain a Zope-transaction-aware
-        wrapper.
-
         'transactional' - True|False, only used for SQLAlchemyDA *don't change it*
 
         'name' can be set to register the wrapper automatically  in order
@@ -52,20 +50,25 @@ def createSAWrapper(dsn, model=None, forZope=False, name=None, transactional=Tru
 
         'session_options' can be set to a dict containing keyword parameters
         passed to create_session or sessionmaker.
+
+        'extension_options' can be set to a dict containing keyword parameters
+        passed to ZopeTransactionExtension()
     """
 
     url = make_url(dsn)
     driver = url.drivername
 
-    klass = forZope and ZopeBaseWrapper or BaseWrapper
+    klass = ZopeWrapper 
 
     if driver == 'postgres':
-        klass = forZope and ZopePostgresWrapper or PythonPostgresWrapper
+        klass = ZopePostgresWrapper
 
     wrapper = klass(dsn, model, 
                     transactional=transactional, 
                     engine_options=engine_options, 
-                    session_options=session_options, **kw)
+                    session_options=session_options, 
+                    extension_options=extension_options,
+                    **kw)
     if name is not None:
         registerSAWrapper(wrapper, name)
 
@@ -155,4 +158,4 @@ def allSAWrapperNames():
 
 
 if __name__ == '__main__':
-    print createSAWrapper('postgres://test:test@db.example.com/TestDB', forZope=True)
+    print createSAWrapper('postgres://test:test@db.example.com/TestDB')
